=====
pyrpc
=====

Pyrpc is a Django app to handle JSON Remote Procedure Calls 
using Django Rest Framework. 

Detailed documentation is in the "docs" directory.

Quick start
-----------

1. Add "pyrpc" to your INSTALLED_APPS setting like this::

    INSTALLED_APPS = [
        ...
        'pyrpc',
    ]
